Helper function to create a filtering list for computed files by format
Source:R/computed-files.R
computed_files_filter.RdDeprecated. The computed-files endpoint is being removed from the API.
Usage
computed_files_filter(
format_str = c("SINGLE_CELL_EXPERIMENT", "ANN_DATA", "SPATIAL")
)Value
a list suitable for passing as the filters argument to get_computed_file_ids().