Get computed file ids from a sample info list, optionally filtered by criteria
Source:R/computed-files.R
get_computed_file_ids.RdDeprecated. The computed-files endpoint is being removed from the API.
Usage
get_computed_file_ids(info_list, filters = list())Arguments
- info_list
A list object that includes a "computed_files" element, such as returned by
get_sample_info()orget_project_info()- filters
A named list of filtering criteria, where names are fields in the computed_files objects, and values are the desired values to match. Values can be negated by prefixing with "!". For example, to get all non-spatial computed files in SingleCellExperiment format, use: list(format = "SINGLE_CELL_EXPERIMENT", modality = "!SPATIAL").