Returns the full dataset detail, including the $data field showing which
samples are included and processing status fields such as $is_started,
$is_processing, $is_succeeded, and $is_failed.
Arguments
- dataset
the dataset UUID string (such as the value returned by
create_dataset()), or a list with an$idelement (such as the value returned byget_dataset_detail()).- auth_token
an authorization token obtained from
get_auth(); must match the token used to create the dataset.