Returns a single string describing where a dataset is in the processing lifecycle.
Usage
get_dataset_status(dataset, auth_token = Sys.getenv("SCPCA_AUTH_TOKEN"))Arguments
- dataset
the dataset UUID string (such as the value returned by
create_dataset()), or a list with an$idelement (such as the value returned byget_dataset_detail()).- auth_token
an authorization token from
get_auth(). Defaults to theSCPCA_AUTH_TOKENenvironment variable, whichget_auth()sets automatically.
Value
a single character string: one of "pending", "processing", "succeeded", "failed", or "expired".
Details
Possible values are:
"pending": the dataset has not been started"processing": the dataset has been started but is not yet finished"succeeded": processing finished and the dataset is ready to download"expired": processing completed but the generated download has since expired and must be regenerated"failed": processing failed